@@ -65,7 +65,7 @@ class Transformer(object):
                               ]
         outputs = self.call(inputs)
         self.set_outputs(outputs)
-        self.model = Model(self.inputs,self.outptus,name=self.name)
+        self.model = Model(self.inputs,self.outputs,name=self.name)
         self.built = True
     
     def call(self,inputs):
@@ -84,7 +84,7 @@ class Transformer(object):
         
         arguments = arguments or {}
         
-        name = kwargs['name']
+        name = kwargs.get('name')
         if name not in self.layers:
             layer = layer(**kwargs)
             name=layer.name
@@ -275,7 +275,7 @@ class BERT(Transformer):
                         input_dim=self.max_position,
                         output_dim=self.embedding_size,
                         merge_mode='add',
-                        embedding_initializer=self.initializer,
+                        embeddings_initializer=self.initializer,
                         custom_position_ids=self.custom_position_ids,
                         name='Embedding-Position'
                      )
@@ -283,7 +283,7 @@ class BERT(Transformer):
         x = self.apply(
                         inputs=self.simplify([x,z]),
                         layer=LayerNormalization,
-                        conditinal=(z is not None),
+                        conditional=(z is not None),
                         hidden_units=self.layer_norm_conds[1],
                         hidden_activation=self.layer_norm_conds[2],
                         hidden_initializer=self.initializer,
